/*
 *  TOPPERS/JSP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Just Standard Profile Kernel
 * 
 *  Copyright (C) 2000-2003 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 * 
 *  嵭Ԥϡʲ (1)(4) ξ狼Free Software Foundation 
 *  ˤäƸɽƤ GNU General Public License  Version 2 ˵
 *  ҤƤ˸¤ꡤܥեȥܥեȥ
 *  ѤΤޤࡥʲƱˤѡʣѡۡʰʲ
 *  ѤȸƤ֡ˤ뤳Ȥ̵ǵ롥
 *  (1) ܥեȥ򥽡ɤηѤˤϡ嵭
 *      ɽѾ浪Ӳ̵ݾڵ꤬Τޤޤηǥ
 *      ˴ޤޤƤ뤳ȡ
 *  (2) ܥեȥ򡤥饤֥ʤɡ¾Υեȥȯ˻
 *      ѤǤǺۤˤϡۤȼɥȡ
 *      ԥޥ˥奢ʤɡˤˡ嵭ɽѾ浪Ӳ
 *      ̵ݾڵǺܤ뤳ȡ
 *  (3) ܥեȥ򡤵Ȥ߹ʤɡ¾Υեȥȯ˻
 *      ѤǤʤǺۤˤϡΤ줫ξ
 *      ȡ
 *    (a) ۤȼɥȡѼԥޥ˥奢ʤɡˤˡ嵭
 *        ɽѾ浪Ӳ̵ݾڵǺܤ뤳ȡ
 *    (b) ۤη֤̤ˡˤäơTOPPERSץȤ
 *        𤹤뤳ȡ
 *  (4) ܥեȥѤˤľŪޤϴŪ뤤ʤ»
 *      ⡤嵭ԤTOPPERSץȤդ뤳ȡ
 * 
 *  ܥեȥϡ̵ݾڤ󶡤ƤΤǤ롥嵭Ԥ
 *  TOPPERSץȤϡܥեȥ˴ؤơŬѲǽ
 *  ޤơʤݾڤԤʤޤܥեȥѤˤľ
 *  ŪޤϴŪʤ»˴ؤƤ⡤Ǥʤ
 * 
 *  @(#) $Id: rx63n.h,v 1.4 2015/07/20 14:55:45 ssuzuki Exp $
 */

#ifndef	_RX63N_H_
#define	_RX63N_H_

/*
 * åȯϩ
 */
#define	RX63N_SCKCR		(0x00080020)
#define	RX63N_SCKCR2		(0x00080024)
#define	RX63N_SCKCR3		(0x00080026)
#define	RX63N_PLLCR		(0x00080028)
#define	RX63N_PLLCR2		(0x0008002a)
#define	RX63N_BCKCR		(0x00080030)
#define	RX63N_MOSCCR		(0x00080032)
#define	RX63N_SOSCCR		(0x00080033)
#define	RX63N_LOCOCR		(0x00080034)
#define	RX63N_ILOCOCR		(0x00080035)
#define	RX63N_HOCOCR		(0x00080036)
#define	RX63N_OSTDCR		(0x00080040)
#define	RX63N_OSTDSR		(0x00080041)
#define	RX63N_MOFCR		(0x0008c293)
#define	RX63N_HOCOPCR		(0x0008c294)

/*
 * 㸺ǽ
 */
#define	RX63N_MSTPCRA		(0x00080010)
#define	RX63N_MSTPCRB		(0x00080014)
#define	RX63N_MSTPCRC		(0x00080018)
#define	RX63N_MSTPCRD		(0x0008001c)
#define	RX63N_OPCCR		(0x000800a0)
#define	RX63N_RSTCKCR		(0x000800a1)
#define	RX63N_MOSCWTCR		(0x000800a2)
#define	RX63N_SOSCWTCR		(0x000800a3)
#define	RX63N_PLLWTCR		(0x000800a6)
#define	RX63N_DPSBYCR		(0x0008c280)
#define	RX63N_DPSIER0		(0x0008c282)
#define	RX63N_DPSIER1		(0x0008c283)
#define	RX63N_DPSIER2		(0x0008c284)
#define	RX63N_DPSIER3		(0x0008c285)
#define	RX63N_DPSIFR0		(0x0008c286)
#define	RX63N_DPSIFR1		(0x0008c287)
#define	RX63N_DPSIFR2		(0x0008c288)
#define	RX63N_DPSIFR3		(0x0008c289)
#define	RX63N_DPSIEGR0		(0x0008c28a)
#define	RX63N_DPSIEGR1		(0x0008c28b)
#define	RX63N_DPSIEGR2		(0x0008c28c)
#define	RX63N_DPSIEGR3		(0x0008c28d)

/*
 * 쥸饤ȥץƥǽ
 */
#define	RX63N_PRCR		(0x000803fe)

/*
 * ߥȥ(ICUb)
 */
#define	RX63N_IR10		(0x0008700a)
#define	RX63N_IR11		(0x0008700b)
#define	RX63N_IR12		(0x0008700c)
#define	RX63N_IR13		(0x0008700d)
#define	RX63N_IR14		(0x0008700e)
#define	RX63N_IR15		(0x0008700f)
#define	RX63N_IR16		(0x00087010)
#define	RX63N_IR17		(0x00087011)
#define	RX63N_IR18		(0x00087012)
#define	RX63N_IR19		(0x00087013)
#define	RX63N_IR20		(0x00087014)
#define	RX63N_IR21		(0x00087015)
#define	RX63N_IR22		(0x00087016)
#define	RX63N_IR23		(0x00087017)
#define	RX63N_IR24		(0x00087018)
#define	RX63N_IR25		(0x00087019)
#define	RX63N_IR26		(0x0008701a)
#define	RX63N_IR27		(0x0008701b)
#define	RX63N_IR28		(0x0008701c)
#define	RX63N_IR29		(0x0008701d)
#define	RX63N_IR30		(0x0008701e)
#define	RX63N_IR31		(0x0008701f)
#define	RX63N_IR32		(0x00087020)
#define	RX63N_IR33		(0x00087021)
#define	RX63N_IR34		(0x00087022)
#define	RX63N_IR35		(0x00087023)
#define	RX63N_IR36		(0x00087024)
#define	RX63N_IR37		(0x00087025)
#define	RX63N_IR38		(0x00087026)
#define	RX63N_IR39		(0x00087027)
#define	RX63N_IR40		(0x00087028)
#define	RX63N_IR41		(0x00087029)
#define	RX63N_IR42		(0x0008702a)
#define	RX63N_IR43		(0x0008702b)
#define	RX63N_IR44		(0x0008702c)
#define	RX63N_IR45		(0x0008702d)
#define	RX63N_IR46		(0x0008702e)
#define	RX63N_IR47		(0x0008702f)
#define	RX63N_IR48		(0x00087030)
#define	RX63N_IR49		(0x00087031)
#define	RX63N_IR50		(0x00087032)
#define	RX63N_IR51		(0x00087033)
#define	RX63N_IR52		(0x00087034)
#define	RX63N_IR53		(0x00087035)
#define	RX63N_IR54		(0x00087036)
#define	RX63N_IR55		(0x00087037)
#define	RX63N_IR56		(0x00087038)
#define	RX63N_IR57		(0x00087039)
#define	RX63N_IR58		(0x0008703a)
#define	RX63N_IR59		(0x0008703b)
#define	RX63N_IR60		(0x0008703c)
#define	RX63N_IR61		(0x0008703d)
#define	RX63N_IR62		(0x0008703e)
#define	RX63N_IR63		(0x0008703f)
#define	RX63N_IR64		(0x00087040)
#define	RX63N_IR65		(0x00087041)
#define	RX63N_IR66		(0x00087042)
#define	RX63N_IR67		(0x00087043)
#define	RX63N_IR68		(0x00087044)
#define	RX63N_IR69		(0x00087045)
#define	RX63N_IR70		(0x00087046)
#define	RX63N_IR71		(0x00087047)
#define	RX63N_IR72		(0x00087048)
#define	RX63N_IR73		(0x00087049)
#define	RX63N_IR74		(0x0008704a)
#define	RX63N_IR75		(0x0008704b)
#define	RX63N_IR76		(0x0008704c)
#define	RX63N_IR77		(0x0008704d)
#define	RX63N_IR78		(0x0008704e)
#define	RX63N_IR79		(0x0008704f)
#define	RX63N_IR80		(0x00087050)
#define	RX63N_IR81		(0x00087051)
#define	RX63N_IR82		(0x00087052)
#define	RX63N_IR83		(0x00087053)
#define	RX63N_IR84		(0x00087054)
#define	RX63N_IR85		(0x00087055)
#define	RX63N_IR86		(0x00087056)
#define	RX63N_IR87		(0x00087057)
#define	RX63N_IR88		(0x00087058)
#define	RX63N_IR89		(0x00087059)
#define	RX63N_IR90		(0x0008705a)
#define	RX63N_IR91		(0x0008705b)
#define	RX63N_IR92		(0x0008705c)
#define	RX63N_IR93		(0x0008705d)
#define	RX63N_IR94		(0x0008705e)
#define	RX63N_IR95		(0x0008705f)
#define	RX63N_IR96		(0x00087060)
#define	RX63N_IR97		(0x00087061)
#define	RX63N_IR98		(0x00087062)
#define	RX63N_IR99		(0x00087063)
#define	RX63N_IR100		(0x00087064)
#define	RX63N_IR101		(0x00087065)
#define	RX63N_IR102		(0x00087066)
#define	RX63N_IR103		(0x00087067)
#define	RX63N_IR104		(0x00087068)
#define	RX63N_IR105		(0x00087069)
#define	RX63N_IR106		(0x0008706a)
#define	RX63N_IR107		(0x0008706b)
#define	RX63N_IR108		(0x0008706c)
#define	RX63N_IR109		(0x0008706d)
#define	RX63N_IR110		(0x0008706e)
#define	RX63N_IR111		(0x0008706f)
#define	RX63N_IR112		(0x00087070)
#define	RX63N_IR113		(0x00087071)
#define	RX63N_IR114		(0x00087072)
#define	RX63N_IR115		(0x00087073)
#define	RX63N_IR116		(0x00087074)
#define	RX63N_IR117		(0x00087075)
#define	RX63N_IR118		(0x00087076)
#define	RX63N_IR119		(0x00087077)
#define	RX63N_IR120		(0x00087078)
#define	RX63N_IR121		(0x00087079)
#define	RX63N_IR122		(0x0008707a)
#define	RX63N_IR123		(0x0008707b)
#define	RX63N_IR124		(0x0008707c)
#define	RX63N_IR125		(0x0008707d)
#define	RX63N_IR126		(0x0008707e)
#define	RX63N_IR127		(0x0008707f)
#define	RX63N_IR128		(0x00087080)
#define	RX63N_IR129		(0x00087081)
#define	RX63N_IR130		(0x00087082)
#define	RX63N_IR131		(0x00087083)
#define	RX63N_IR132		(0x00087084)
#define	RX63N_IR133		(0x00087085)
#define	RX63N_IR134		(0x00087086)
#define	RX63N_IR135		(0x00087087)
#define	RX63N_IR136		(0x00087088)
#define	RX63N_IR137		(0x00087089)
#define	RX63N_IR138		(0x0008708a)
#define	RX63N_IR139		(0x0008708b)
#define	RX63N_IR140		(0x0008708c)
#define	RX63N_IR141		(0x0008708d)
#define	RX63N_IR142		(0x0008708e)
#define	RX63N_IR143		(0x0008708f)
#define	RX63N_IR144		(0x00087090)
#define	RX63N_IR145		(0x00087091)
#define	RX63N_IR146		(0x00087092)
#define	RX63N_IR147		(0x00087093)
#define	RX63N_IR148		(0x00087094)
#define	RX63N_IR149		(0x00087095)
#define	RX63N_IR150		(0x00087096)
#define	RX63N_IR151		(0x00087097)
#define	RX63N_IR152		(0x00087098)
#define	RX63N_IR153		(0x00087099)
#define	RX63N_IR154		(0x0008709a)
#define	RX63N_IR155		(0x0008709b)
#define	RX63N_IR156		(0x0008709c)
#define	RX63N_IR157		(0x0008709d)
#define	RX63N_IR158		(0x0008709e)
#define	RX63N_IR159		(0x0008709f)
#define	RX63N_IR160		(0x000870a0)
#define	RX63N_IR161		(0x000870a1)
#define	RX63N_IR162		(0x000870a2)
#define	RX63N_IR163		(0x000870a3)
#define	RX63N_IR164		(0x000870a4)
#define	RX63N_IR165		(0x000870a5)
#define	RX63N_IR166		(0x000870a6)
#define	RX63N_IR167		(0x000870a7)
#define	RX63N_IR168		(0x000870a8)
#define	RX63N_IR169		(0x000870a9)
#define	RX63N_IR170		(0x000870aa)
#define	RX63N_IR171		(0x000870ab)
#define	RX63N_IR172		(0x000870ac)
#define	RX63N_IR173		(0x000870ad)
#define	RX63N_IR174		(0x000870ae)
#define	RX63N_IR175		(0x000870af)
#define	RX63N_IR176		(0x000870b0)
#define	RX63N_IR177		(0x000870b1)
#define	RX63N_IR178		(0x000870b2)
#define	RX63N_IR179		(0x000870b3)
#define	RX63N_IR180		(0x000870b4)
#define	RX63N_IR181		(0x000870b5)
#define	RX63N_IR182		(0x000870b6)
#define	RX63N_IR183		(0x000870b7)
#define	RX63N_IR184		(0x000870b8)
#define	RX63N_IR185		(0x000870b9)
#define	RX63N_IR186		(0x000870ba)
#define	RX63N_IR187		(0x000870bb)
#define	RX63N_IR188		(0x000870bc)
#define	RX63N_IR189		(0x000870bd)
#define	RX63N_IR190		(0x000870be)
#define	RX63N_IR191		(0x000870bf)
#define	RX63N_IR192		(0x000870c0)
#define	RX63N_IR193		(0x000870c1)
#define	RX63N_IR194		(0x000870c2)
#define	RX63N_IR195		(0x000870c3)
#define	RX63N_IR196		(0x000870c4)
#define	RX63N_IR197		(0x000870c5)
#define	RX63N_IR198		(0x000870c6)
#define	RX63N_IR199		(0x000870c7)
#define	RX63N_IR200		(0x000870c8)
#define	RX63N_IR201		(0x000870c9)
#define	RX63N_IR202		(0x000870ca)
#define	RX63N_IR203		(0x000870cb)
#define	RX63N_IR204		(0x000870cc)
#define	RX63N_IR205		(0x000870cd)
#define	RX63N_IR206		(0x000870ce)
#define	RX63N_IR207		(0x000870cf)
#define	RX63N_IR208		(0x000870d0)
#define	RX63N_IR209		(0x000870d1)
#define	RX63N_IR210		(0x000870d2)
#define	RX63N_IR211		(0x000870d3)
#define	RX63N_IR212		(0x000870d4)
#define	RX63N_IR213		(0x000870d5)
#define	RX63N_IR214		(0x000870d6)
#define	RX63N_IR215		(0x000870d7)
#define	RX63N_IR216		(0x000870d8)
#define	RX63N_IR217		(0x000870d9)
#define	RX63N_IR218		(0x000870da)
#define	RX63N_IR219		(0x000870db)
#define	RX63N_IR220		(0x000870dc)
#define	RX63N_IR221		(0x000870dd)
#define	RX63N_IR222		(0x000870de)
#define	RX63N_IR223		(0x000870df)
#define	RX63N_IR224		(0x000870e0)
#define	RX63N_IR225		(0x000870e1)
#define	RX63N_IR226		(0x000870e2)
#define	RX63N_IR227		(0x000870e3)
#define	RX63N_IR228		(0x000870e4)
#define	RX63N_IR229		(0x000870e5)
#define	RX63N_IR230		(0x000870e6)
#define	RX63N_IR231		(0x000870e7)
#define	RX63N_IR232		(0x000870e8)
#define	RX63N_IR233		(0x000870e9)
#define	RX63N_IR234		(0x000870ea)
#define	RX63N_IR235		(0x000870eb)
#define	RX63N_IR236		(0x000870ec)
#define	RX63N_IR237		(0x000870ed)
#define	RX63N_IR238		(0x000870ee)
#define	RX63N_IR239		(0x000870ef)
#define	RX63N_IR240		(0x000870f0)
#define	RX63N_IR241		(0x000870f1)
#define	RX63N_IR242		(0x000870f2)
#define	RX63N_IR243		(0x000870f3)
#define	RX63N_IR244		(0x000870f4)
#define	RX63N_IR245		(0x000870f5)
#define	RX63N_IR246		(0x000870f6)
#define	RX63N_IR247		(0x000870f7)
#define	RX63N_IR248		(0x000870f8)
#define	RX63N_IR249		(0x000870f9)
#define	RX63N_IR250		(0x000870fa)
#define	RX63N_IR251		(0x000870fb)
#define	RX63N_IR252		(0x000870fc)
#define	RX63N_IR253		(0x000870fd)
#define	RX63N_IER02		(0x00087202)
#define	RX63N_IER03		(0x00087203)
#define	RX63N_IER04		(0x00087204)
#define	RX63N_IER05		(0x00087205)
#define	RX63N_IER06		(0x00087206)
#define	RX63N_IER07		(0x00087207)
#define	RX63N_IER08		(0x00087208)
#define	RX63N_IER09		(0x00087209)
#define	RX63N_IER0A		(0x0008720a)
#define	RX63N_IER0B		(0x0008720b)
#define	RX63N_IER0C		(0x0008720c)
#define	RX63N_IER0D		(0x0008720d)
#define	RX63N_IER0E		(0x0008720e)
#define	RX63N_IER0F		(0x0008720f)
#define	RX63N_IER10		(0x00087210)
#define	RX63N_IER11		(0x00087211)
#define	RX63N_IER12		(0x00087212)
#define	RX63N_IER13		(0x00087213)
#define	RX63N_IER14		(0x00087214)
#define	RX63N_IER15		(0x00087215)
#define	RX63N_IER16		(0x00087216)
#define	RX63N_IER17		(0x00087217)
#define	RX63N_IER18		(0x00087218)
#define	RX63N_IER19		(0x00087219)
#define	RX63N_IER1A		(0x0008721a)
#define	RX63N_IER1B		(0x0008721b)
#define	RX63N_IER1C		(0x0008721c)
#define	RX63N_IER1D		(0x0008721d)
#define	RX63N_IER1E		(0x0008721e)
#define	RX63N_IER1F		(0x0008721f)
#define	RX63N_IPR000		(0x00087300)
#define	RX63N_IPR001		(0x00087301)
#define	RX63N_IPR002		(0x00087302)
#define	RX63N_IPR003		(0x00087303)
#define	RX63N_IPR004		(0x00087304)
#define	RX63N_IPR005		(0x00087305)
#define	RX63N_IPR006		(0x00087306)
#define	RX63N_IPR007		(0x00087307)
#define	RX63N_IPR008		(0x00087308)
#define	RX63N_IPR009		(0x00087309)
#define	RX63N_IPR010		(0x0008730a)
#define	RX63N_IPR011		(0x0008730b)
#define	RX63N_IPR012		(0x0008730c)
#define	RX63N_IPR013		(0x0008730d)
#define	RX63N_IPR014		(0x0008730e)
#define	RX63N_IPR015		(0x0008730f)
#define	RX63N_IPR016		(0x00087310)
#define	RX63N_IPR017		(0x00087311)
#define	RX63N_IPR018		(0x00087312)
#define	RX63N_IPR019		(0x00087313)
#define	RX63N_IPR020		(0x00087314)
#define	RX63N_IPR021		(0x00087315)
#define	RX63N_IPR022		(0x00087316)
#define	RX63N_IPR023		(0x00087317)
#define	RX63N_IPR024		(0x00087318)
#define	RX63N_IPR025		(0x00087319)
#define	RX63N_IPR026		(0x0008731a)
#define	RX63N_IPR027		(0x0008731b)
#define	RX63N_IPR028		(0x0008731c)
#define	RX63N_IPR029		(0x0008731d)
#define	RX63N_IPR030		(0x0008731e)
#define	RX63N_IPR031		(0x0008731f)
#define	RX63N_IPR032		(0x00087320)
#define	RX63N_IPR033		(0x00087321)
#define	RX63N_IPR034		(0x00087322)
#define	RX63N_IPR035		(0x00087323)
#define	RX63N_IPR036		(0x00087324)
#define	RX63N_IPR037		(0x00087325)
#define	RX63N_IPR038		(0x00087326)
#define	RX63N_IPR039		(0x00087327)
#define	RX63N_IPR040		(0x00087328)
#define	RX63N_IPR041		(0x00087329)
#define	RX63N_IPR042		(0x0008732a)
#define	RX63N_IPR043		(0x0008732b)
#define	RX63N_IPR044		(0x0008732c)
#define	RX63N_IPR045		(0x0008732d)
#define	RX63N_IPR046		(0x0008732e)
#define	RX63N_IPR047		(0x0008732f)
#define	RX63N_IPR048		(0x00087330)
#define	RX63N_IPR049		(0x00087331)
#define	RX63N_IPR050		(0x00087332)
#define	RX63N_IPR051		(0x00087333)
#define	RX63N_IPR052		(0x00087334)
#define	RX63N_IPR053		(0x00087335)
#define	RX63N_IPR054		(0x00087336)
#define	RX63N_IPR055		(0x00087337)
#define	RX63N_IPR056		(0x00087338)
#define	RX63N_IPR057		(0x00087339)
#define	RX63N_IPR058		(0x0008733a)
#define	RX63N_IPR059		(0x0008733b)
#define	RX63N_IPR060		(0x0008733c)
#define	RX63N_IPR061		(0x0008733d)
#define	RX63N_IPR062		(0x0008733e)
#define	RX63N_IPR063		(0x0008733f)
#define	RX63N_IPR064		(0x00087340)
#define	RX63N_IPR065		(0x00087341)
#define	RX63N_IPR066		(0x00087342)
#define	RX63N_IPR067		(0x00087343)
#define	RX63N_IPR068		(0x00087344)
#define	RX63N_IPR069		(0x00087345)
#define	RX63N_IPR070		(0x00087346)
#define	RX63N_IPR071		(0x00087347)
#define	RX63N_IPR072		(0x00087348)
#define	RX63N_IPR073		(0x00087349)
#define	RX63N_IPR074		(0x0008734a)
#define	RX63N_IPR075		(0x0008734b)
#define	RX63N_IPR076		(0x0008734c)
#define	RX63N_IPR077		(0x0008734d)
#define	RX63N_IPR078		(0x0008734e)
#define	RX63N_IPR079		(0x0008734f)
#define	RX63N_IPR080		(0x00087350)
#define	RX63N_IPR081		(0x00087351)
#define	RX63N_IPR082		(0x00087352)
#define	RX63N_IPR083		(0x00087353)
#define	RX63N_IPR084		(0x00087354)
#define	RX63N_IPR085		(0x00087355)
#define	RX63N_IPR086		(0x00087356)
#define	RX63N_IPR087		(0x00087357)
#define	RX63N_IPR088		(0x00087358)
#define	RX63N_IPR089		(0x00087359)
#define	RX63N_IPR090		(0x0008735a)
#define	RX63N_IPR091		(0x0008735b)
#define	RX63N_IPR092		(0x0008735c)
#define	RX63N_IPR093		(0x0008735d)
#define	RX63N_IPR094		(0x0008735e)
#define	RX63N_IPR095		(0x0008735f)
#define	RX63N_IPR096		(0x00087360)
#define	RX63N_IPR097		(0x00087361)
#define	RX63N_IPR098		(0x00087362)
#define	RX63N_IPR099		(0x00087363)
#define	RX63N_IPR100		(0x00087364)
#define	RX63N_IPR101		(0x00087365)
#define	RX63N_IPR102		(0x00087366)
#define	RX63N_IPR103		(0x00087367)
#define	RX63N_IPR104		(0x00087368)
#define	RX63N_IPR105		(0x00087369)
#define	RX63N_IPR106		(0x0008736a)
#define	RX63N_IPR107		(0x0008736b)
#define	RX63N_IPR108		(0x0008736c)
#define	RX63N_IPR109		(0x0008736d)
#define	RX63N_IPR110		(0x0008736e)
#define	RX63N_IPR111		(0x0008736f)
#define	RX63N_IPR112		(0x00087370)
#define	RX63N_IPR113		(0x00087371)
#define	RX63N_IPR114		(0x00087372)
#define	RX63N_IPR115		(0x00087373)
#define	RX63N_IPR116		(0x00087374)
#define	RX63N_IPR117		(0x00087375)
#define	RX63N_IPR118		(0x00087376)
#define	RX63N_IPR119		(0x00087377)
#define	RX63N_IPR120		(0x00087378)
#define	RX63N_IPR121		(0x00087379)
#define	RX63N_IPR122		(0x0008737a)
#define	RX63N_IPR123		(0x0008737b)
#define	RX63N_IPR124		(0x0008737c)
#define	RX63N_IPR125		(0x0008737d)
#define	RX63N_IPR126		(0x0008737e)
#define	RX63N_IPR127		(0x0008737f)
#define	RX63N_IPR128		(0x00087380)
#define	RX63N_IPR129		(0x00087381)
#define	RX63N_IPR130		(0x00087382)
#define	RX63N_IPR131		(0x00087383)
#define	RX63N_IPR132		(0x00087384)
#define	RX63N_IPR133		(0x00087385)
#define	RX63N_IPR134		(0x00087386)
#define	RX63N_IPR135		(0x00087387)
#define	RX63N_IPR136		(0x00087388)
#define	RX63N_IPR137		(0x00087389)
#define	RX63N_IPR138		(0x0008738a)
#define	RX63N_IPR139		(0x0008738b)
#define	RX63N_IPR140		(0x0008738c)
#define	RX63N_IPR141		(0x0008738d)
#define	RX63N_IPR142		(0x0008738e)
#define	RX63N_IPR143		(0x0008738f)
#define	RX63N_IPR144		(0x00087390)
#define	RX63N_IPR145		(0x00087391)
#define	RX63N_IPR146		(0x00087392)
#define	RX63N_IPR147		(0x00087393)
#define	RX63N_IPR148		(0x00087394)
#define	RX63N_IPR149		(0x00087395)
#define	RX63N_IPR150		(0x00087396)
#define	RX63N_IPR151		(0x00087397)
#define	RX63N_IPR152		(0x00087398)
#define	RX63N_IPR153		(0x00087399)
#define	RX63N_IPR154		(0x0008739a)
#define	RX63N_IPR155		(0x0008739b)
#define	RX63N_IPR156		(0x0008739c)
#define	RX63N_IPR157		(0x0008739d)
#define	RX63N_IPR158		(0x0008739e)
#define	RX63N_IPR159		(0x0008739f)
#define	RX63N_IPR160		(0x000873a0)
#define	RX63N_IPR161		(0x000873a1)
#define	RX63N_IPR162		(0x000873a2)
#define	RX63N_IPR163		(0x000873a3)
#define	RX63N_IPR164		(0x000873a4)
#define	RX63N_IPR165		(0x000873a5)
#define	RX63N_IPR166		(0x000873a6)
#define	RX63N_IPR167		(0x000873a7)
#define	RX63N_IPR168		(0x000873a8)
#define	RX63N_IPR169		(0x000873a9)
#define	RX63N_IPR170		(0x000873aa)
#define	RX63N_IPR171		(0x000873ab)
#define	RX63N_IPR172		(0x000873ac)
#define	RX63N_IPR173		(0x000873ad)
#define	RX63N_IPR174		(0x000873ae)
#define	RX63N_IPR175		(0x000873af)
#define	RX63N_IPR176		(0x000873b0)
#define	RX63N_IPR177		(0x000873b1)
#define	RX63N_IPR178		(0x000873b2)
#define	RX63N_IPR179		(0x000873b3)
#define	RX63N_IPR180		(0x000873b4)
#define	RX63N_IPR181		(0x000873b5)
#define	RX63N_IPR182		(0x000873b6)
#define	RX63N_IPR183		(0x000873b7)
#define	RX63N_IPR184		(0x000873b8)
#define	RX63N_IPR185		(0x000873b9)
#define	RX63N_IPR186		(0x000873ba)
#define	RX63N_IPR187		(0x000873bb)
#define	RX63N_IPR188		(0x000873bc)
#define	RX63N_IPR189		(0x000873bd)
#define	RX63N_IPR190		(0x000873be)
#define	RX63N_IPR191		(0x000873bf)
#define	RX63N_IPR192		(0x000873c0)
#define	RX63N_IPR193		(0x000873c1)
#define	RX63N_IPR194		(0x000873c2)
#define	RX63N_IPR195		(0x000873c3)
#define	RX63N_IPR196		(0x000873c4)
#define	RX63N_IPR197		(0x000873c5)
#define	RX63N_IPR198		(0x000873c6)
#define	RX63N_IPR199		(0x000873c7)
#define	RX63N_IPR200		(0x000873c8)
#define	RX63N_IPR201		(0x000873c9)
#define	RX63N_IPR202		(0x000873ca)
#define	RX63N_IPR203		(0x000873cb)
#define	RX63N_IPR204		(0x000873cc)
#define	RX63N_IPR205		(0x000873cd)
#define	RX63N_IPR206		(0x000873ce)
#define	RX63N_IPR207		(0x000873cf)
#define	RX63N_IPR208		(0x000873d0)
#define	RX63N_IPR209		(0x000873d1)
#define	RX63N_IPR210		(0x000873d2)
#define	RX63N_IPR211		(0x000873d3)
#define	RX63N_IPR212		(0x000873d4)
#define	RX63N_IPR213		(0x000873d5)
#define	RX63N_IPR214		(0x000873d6)
#define	RX63N_IPR215		(0x000873d7)
#define	RX63N_IPR216		(0x000873d8)
#define	RX63N_IPR217		(0x000873d9)
#define	RX63N_IPR218		(0x000873da)
#define	RX63N_IPR219		(0x000873db)
#define	RX63N_IPR220		(0x000873dc)
#define	RX63N_IPR221		(0x000873dd)
#define	RX63N_IPR222		(0x000873de)
#define	RX63N_IPR223		(0x000873df)
#define	RX63N_IPR224		(0x000873e0)
#define	RX63N_IPR225		(0x000873e1)
#define	RX63N_IPR226		(0x000873e2)
#define	RX63N_IPR227		(0x000873e3)
#define	RX63N_IPR228		(0x000873e4)
#define	RX63N_IPR229		(0x000873e5)
#define	RX63N_IPR230		(0x000873e6)
#define	RX63N_IPR231		(0x000873e7)
#define	RX63N_IPR232		(0x000873e8)
#define	RX63N_IPR233		(0x000873e9)
#define	RX63N_IPR234		(0x000873ea)
#define	RX63N_IPR235		(0x000873eb)
#define	RX63N_IPR236		(0x000873ec)
#define	RX63N_IPR237		(0x000873ed)
#define	RX63N_IPR238		(0x000873ee)
#define	RX63N_IPR239		(0x000873ef)
#define	RX63N_IPR240		(0x000873f0)
#define	RX63N_IPR241		(0x000873f1)
#define	RX63N_IPR242		(0x000873f2)
#define	RX63N_IPR243		(0x000873f3)
#define	RX63N_IPR244		(0x000873f4)
#define	RX63N_IPR245		(0x000873f5)
#define	RX63N_IPR246		(0x000873f6)
#define	RX63N_IPR247		(0x000873f7)
#define	RX63N_IPR248		(0x000873f8)
#define	RX63N_IPR249		(0x000873f9)
#define	RX63N_IPR250		(0x000873fa)
#define	RX63N_IPR251		(0x000873fb)
#define	RX63N_IPR252		(0x000873fc)
#define	RX63N_IPR253		(0x000873fd)
#define	RX63N_FIR		(0x000872f0)
#define	RX63N_SWINTR		(0x000872e0)
#define	RX63N_DTCER027		(0x0008711b)
#define	RX63N_DTCER028		(0x0008711c)
#define	RX63N_DTCER029		(0x0008711d)
#define	RX63N_DTCER030		(0x0008711e)
#define	RX63N_DTCER031		(0x0008711f)
#define	RX63N_DTCER032		(0x00087120)
#define	RX63N_DTCER033		(0x00087121)
#define	RX63N_DTCER034		(0x00087122)
#define	RX63N_DTCER035		(0x00087123)
#define	RX63N_DTCER036		(0x00087124)
#define	RX63N_DTCER037		(0x00087125)
#define	RX63N_DTCER038		(0x00087126)
#define	RX63N_DTCER039		(0x00087127)
#define	RX63N_DTCER040		(0x00087128)
#define	RX63N_DTCER041		(0x00087129)
#define	RX63N_DTCER042		(0x0008712a)
#define	RX63N_DTCER043		(0x0008712b)
#define	RX63N_DTCER044		(0x0008712c)
#define	RX63N_DTCER045		(0x0008712d)
#define	RX63N_DTCER046		(0x0008712e)
#define	RX63N_DTCER047		(0x0008712f)
#define	RX63N_DTCER048		(0x00087130)
#define	RX63N_DTCER049		(0x00087131)
#define	RX63N_DTCER050		(0x00087132)
#define	RX63N_DTCER051		(0x00087133)
#define	RX63N_DTCER052		(0x00087134)
#define	RX63N_DTCER053		(0x00087135)
#define	RX63N_DTCER054		(0x00087136)
#define	RX63N_DTCER055		(0x00087137)
#define	RX63N_DTCER056		(0x00087138)
#define	RX63N_DTCER057		(0x00087139)
#define	RX63N_DTCER058		(0x0008713a)
#define	RX63N_DTCER059		(0x0008713b)
#define	RX63N_DTCER060		(0x0008713c)
#define	RX63N_DTCER061		(0x0008713d)
#define	RX63N_DTCER062		(0x0008713e)
#define	RX63N_DTCER063		(0x0008713f)
#define	RX63N_DTCER064		(0x00087140)
#define	RX63N_DTCER065		(0x00087141)
#define	RX63N_DTCER066		(0x00087142)
#define	RX63N_DTCER067		(0x00087143)
#define	RX63N_DTCER068		(0x00087144)
#define	RX63N_DTCER069		(0x00087145)
#define	RX63N_DTCER070		(0x00087146)
#define	RX63N_DTCER071		(0x00087147)
#define	RX63N_DTCER072		(0x00087148)
#define	RX63N_DTCER073		(0x00087149)
#define	RX63N_DTCER074		(0x0008714a)
#define	RX63N_DTCER075		(0x0008714b)
#define	RX63N_DTCER076		(0x0008714c)
#define	RX63N_DTCER077		(0x0008714d)
#define	RX63N_DTCER078		(0x0008714e)
#define	RX63N_DTCER079		(0x0008714f)
#define	RX63N_DTCER080		(0x00087150)
#define	RX63N_DTCER081		(0x00087151)
#define	RX63N_DTCER082		(0x00087152)
#define	RX63N_DTCER083		(0x00087153)
#define	RX63N_DTCER084		(0x00087154)
#define	RX63N_DTCER085		(0x00087155)
#define	RX63N_DTCER086		(0x00087156)
#define	RX63N_DTCER087		(0x00087157)
#define	RX63N_DTCER088		(0x00087158)
#define	RX63N_DTCER089		(0x00087159)
#define	RX63N_DTCER090		(0x0008715a)
#define	RX63N_DTCER091		(0x0008715b)
#define	RX63N_DTCER092		(0x0008715c)
#define	RX63N_DTCER093		(0x0008715d)
#define	RX63N_DTCER094		(0x0008715e)
#define	RX63N_DTCER095		(0x0008715f)
#define	RX63N_DTCER096		(0x00087160)
#define	RX63N_DTCER097		(0x00087161)
#define	RX63N_DTCER098		(0x00087162)
#define	RX63N_DTCER099		(0x00087163)
#define	RX63N_DTCER100		(0x00087164)
#define	RX63N_DTCER101		(0x00087165)
#define	RX63N_DTCER102		(0x00087166)
#define	RX63N_DTCER103		(0x00087167)
#define	RX63N_DTCER104		(0x00087168)
#define	RX63N_DTCER105		(0x00087169)
#define	RX63N_DTCER106		(0x0008716a)
#define	RX63N_DTCER107		(0x0008716b)
#define	RX63N_DTCER108		(0x0008716c)
#define	RX63N_DTCER109		(0x0008716d)
#define	RX63N_DTCER110		(0x0008716e)
#define	RX63N_DTCER111		(0x0008716f)
#define	RX63N_DTCER112		(0x00087170)
#define	RX63N_DTCER113		(0x00087171)
#define	RX63N_DTCER114		(0x00087172)
#define	RX63N_DTCER115		(0x00087173)
#define	RX63N_DTCER116		(0x00087174)
#define	RX63N_DTCER117		(0x00087175)
#define	RX63N_DTCER118		(0x00087176)
#define	RX63N_DTCER119		(0x00087177)
#define	RX63N_DTCER120		(0x00087178)
#define	RX63N_DTCER121		(0x00087179)
#define	RX63N_DTCER122		(0x0008717a)
#define	RX63N_DTCER123		(0x0008717b)
#define	RX63N_DTCER124		(0x0008717c)
#define	RX63N_DTCER125		(0x0008717d)
#define	RX63N_DTCER126		(0x0008717e)
#define	RX63N_DTCER127		(0x0008717f)
#define	RX63N_DTCER128		(0x00087180)
#define	RX63N_DTCER129		(0x00087181)
#define	RX63N_DTCER130		(0x00087182)
#define	RX63N_DTCER131		(0x00087183)
#define	RX63N_DTCER132		(0x00087184)
#define	RX63N_DTCER133		(0x00087185)
#define	RX63N_DTCER134		(0x00087186)
#define	RX63N_DTCER135		(0x00087187)
#define	RX63N_DTCER136		(0x00087188)
#define	RX63N_DTCER137		(0x00087189)
#define	RX63N_DTCER138		(0x0008718a)
#define	RX63N_DTCER139		(0x0008718b)
#define	RX63N_DTCER140		(0x0008718c)
#define	RX63N_DTCER141		(0x0008718d)
#define	RX63N_DTCER142		(0x0008718e)
#define	RX63N_DTCER143		(0x0008718f)
#define	RX63N_DTCER144		(0x00087190)
#define	RX63N_DTCER145		(0x00087191)
#define	RX63N_DTCER146		(0x00087192)
#define	RX63N_DTCER147		(0x00087193)
#define	RX63N_DTCER148		(0x00087194)
#define	RX63N_DTCER149		(0x00087195)
#define	RX63N_DTCER150		(0x00087196)
#define	RX63N_DTCER151		(0x00087197)
#define	RX63N_DTCER152		(0x00087198)
#define	RX63N_DTCER153		(0x00087199)
#define	RX63N_DTCER154		(0x0008719a)
#define	RX63N_DTCER155		(0x0008719b)
#define	RX63N_DTCER156		(0x0008719c)
#define	RX63N_DTCER157		(0x0008719d)
#define	RX63N_DTCER158		(0x0008719e)
#define	RX63N_DTCER159		(0x0008719f)
#define	RX63N_DTCER160		(0x000871a0)
#define	RX63N_DTCER161		(0x000871a1)
#define	RX63N_DTCER162		(0x000871a2)
#define	RX63N_DTCER163		(0x000871a3)
#define	RX63N_DTCER164		(0x000871a4)
#define	RX63N_DTCER165		(0x000871a5)
#define	RX63N_DTCER166		(0x000871a6)
#define	RX63N_DTCER167		(0x000871a7)
#define	RX63N_DTCER168		(0x000871a8)
#define	RX63N_DTCER169		(0x000871a9)
#define	RX63N_DTCER170		(0x000871aa)
#define	RX63N_DTCER171		(0x000871ab)
#define	RX63N_DTCER172		(0x000871ac)
#define	RX63N_DTCER173		(0x000871ad)
#define	RX63N_DTCER174		(0x000871ae)
#define	RX63N_DTCER175		(0x000871af)
#define	RX63N_DTCER176		(0x000871b0)
#define	RX63N_DTCER177		(0x000871b1)
#define	RX63N_DTCER178		(0x000871b2)
#define	RX63N_DTCER179		(0x000871b3)
#define	RX63N_DTCER180		(0x000871b4)
#define	RX63N_DTCER181		(0x000871b5)
#define	RX63N_DTCER182		(0x000871b6)
#define	RX63N_DTCER183		(0x000871b7)
#define	RX63N_DTCER184		(0x000871b8)
#define	RX63N_DTCER185		(0x000871b9)
#define	RX63N_DTCER186		(0x000871ba)
#define	RX63N_DTCER187		(0x000871bb)
#define	RX63N_DTCER188		(0x000871bc)
#define	RX63N_DTCER189		(0x000871bd)
#define	RX63N_DTCER190		(0x000871be)
#define	RX63N_DTCER191		(0x000871bf)
#define	RX63N_DTCER192		(0x000871c0)
#define	RX63N_DTCER193		(0x000871c1)
#define	RX63N_DTCER194		(0x000871c2)
#define	RX63N_DTCER195		(0x000871c3)
#define	RX63N_DTCER196		(0x000871c4)
#define	RX63N_DTCER197		(0x000871c5)
#define	RX63N_DTCER198		(0x000871c6)
#define	RX63N_DTCER199		(0x000871c7)
#define	RX63N_DTCER200		(0x000871c8)
#define	RX63N_DTCER201		(0x000871c9)
#define	RX63N_DTCER202		(0x000871ca)
#define	RX63N_DTCER203		(0x000871cb)
#define	RX63N_DTCER204		(0x000871cc)
#define	RX63N_DTCER205		(0x000871cd)
#define	RX63N_DTCER206		(0x000871ce)
#define	RX63N_DTCER207		(0x000871cf)
#define	RX63N_DTCER208		(0x000871d0)
#define	RX63N_DTCER209		(0x000871d1)
#define	RX63N_DTCER210		(0x000871d2)
#define	RX63N_DTCER211		(0x000871d3)
#define	RX63N_DTCER212		(0x000871d4)
#define	RX63N_DTCER213		(0x000871d5)
#define	RX63N_DTCER214		(0x000871d6)
#define	RX63N_DTCER215		(0x000871d7)
#define	RX63N_DTCER216		(0x000871d8)
#define	RX63N_DTCER217		(0x000871d9)
#define	RX63N_DTCER218		(0x000871da)
#define	RX63N_DTCER219		(0x000871db)
#define	RX63N_DTCER220		(0x000871dc)
#define	RX63N_DTCER221		(0x000871dd)
#define	RX63N_DTCER222		(0x000871de)
#define	RX63N_DTCER223		(0x000871df)
#define	RX63N_DTCER224		(0x000871e0)
#define	RX63N_DTCER225		(0x000871e1)
#define	RX63N_DTCER226		(0x000871e2)
#define	RX63N_DTCER227		(0x000871e3)
#define	RX63N_DTCER228		(0x000871e4)
#define	RX63N_DTCER229		(0x000871e5)
#define	RX63N_DTCER230		(0x000871e6)
#define	RX63N_DTCER231		(0x000871e7)
#define	RX63N_DTCER232		(0x000871e8)
#define	RX63N_DTCER233		(0x000871e9)
#define	RX63N_DTCER234		(0x000871ea)
#define	RX63N_DTCER235		(0x000871eb)
#define	RX63N_DTCER236		(0x000871ec)
#define	RX63N_DTCER237		(0x000871ed)
#define	RX63N_DTCER238		(0x000871ee)
#define	RX63N_DTCER239		(0x000871ef)
#define	RX63N_DTCER240		(0x000871f0)
#define	RX63N_DTCER241		(0x000871f1)
#define	RX63N_DTCER242		(0x000871f2)
#define	RX63N_DTCER243		(0x000871f3)
#define	RX63N_DTCER244		(0x000871f4)
#define	RX63N_DTCER245		(0x000871f5)
#define	RX63N_DTCER246		(0x000871f6)
#define	RX63N_DTCER247		(0x000871f7)
#define	RX63N_DTCER248		(0x000871f8)
#define	RX63N_DTCER249		(0x000871f9)
#define	RX63N_DTCER250		(0x000871fa)
#define	RX63N_DTCER251		(0x000871fb)
#define	RX63N_DMRSR0		(0x00087400)
#define	RX63N_DMRSR1		(0x00087404)
#define	RX63N_DMRSR2		(0x00087408)
#define	RX63N_DMRSR3		(0x0008740c)
#define	RX63N_IRQCR0		(0x00087500)
#define	RX63N_IRQCR1		(0x00087501)
#define	RX63N_IRQCR2		(0x00087502)
#define	RX63N_IRQCR3		(0x00087503)
#define	RX63N_IRQCR4		(0x00087504)
#define	RX63N_IRQCR5		(0x00087505)
#define	RX63N_IRQCR6		(0x00087506)
#define	RX63N_IRQCR7		(0x00087507)
#define	RX63N_IRQCR8		(0x00087508)
#define	RX63N_IRQCR9		(0x00087509)
#define	RX63N_IRQCR10		(0x0008750a)
#define	RX63N_IRQCR11		(0x0008750b)
#define	RX63N_IRQCR12		(0x0008750c)
#define	RX63N_IRQCR13		(0x0008750d)
#define	RX63N_IRQCR14		(0x0008750e)
#define	RX63N_IRQCR15		(0x0008750f)
#define	RX63N_IRQFLTE0		(0x00087510)
#define	RX63N_IRQFLTE1		(0x00087511)
#define	RX63N_IRQFLTC0		(0x00087514)
#define	RX63N_IRQFLTC1		(0x00087516)
#define	RX63N_NMISR		(0x00087580)
#define	RX63N_NMIER		(0x00087581)
#define	RX63N_NMICLR		(0x00087582)
#define	RX63N_NMICR		(0x00087583)
#define	RX63N_NMIFLTE		(0x00087590)
#define	RX63N_NMIFLTC		(0x00087594)
#define	RX63N_GRP00		(0x0008c300)
#define	RX63N_GRP01		(0x0008c304)
#define	RX63N_GRP02		(0x0008c308)
#define	RX63N_GRP03		(0x0008c30c)
#define	RX63N_GRP04		(0x0008c310)
#define	RX63N_GRP05		(0x0008c314)
#define	RX63N_GRP06		(0x0008c318)
#define	RX63N_GRP12		(0x0008c330)
#define	RX63N_GEN00		(0x0008c340)
#define	RX63N_GEN01		(0x0008c344)
#define	RX63N_GEN02		(0x0008c348)
#define	RX63N_GEN03		(0x0008c34c)
#define	RX63N_GEN04		(0x0008c350)
#define	RX63N_GEN05		(0x0008c354)
#define	RX63N_GEN06		(0x0008c358)
#define	RX63N_GEN12		(0x0008c370)
#define	RX63N_GCR00		(0x0008c380)
#define	RX63N_GCR01		(0x0008c384)
#define	RX63N_GCR02		(0x0008c388)
#define	RX63N_GCR03		(0x0008c38c)
#define	RX63N_GCR04		(0x0008c390)
#define	RX63N_GCR05		(0x0008c394)
#define	RX63N_GCR06		(0x0008c398)
#define	RX63N_SEL		(0x0008c3c0)

/*
 * I/O ݡ
 */
#define	RX63N_PORT0_PDR		(0x0008c000)
#define	RX63N_PORT1_PDR		(0x0008c001)
#define	RX63N_PORT2_PDR		(0x0008c002)
#define	RX63N_PORT3_PDR		(0x0008c003)
#define	RX63N_PORT4_PDR		(0x0008c004)
#define	RX63N_PORT5_PDR		(0x0008c005)
#define	RX63N_PORT6_PDR		(0x0008c006)
#define	RX63N_PORT7_PDR		(0x0008c007)
#define	RX63N_PORT8_PDR		(0x0008c008)
#define	RX63N_PORT9_PDR		(0x0008c009)
#define	RX63N_PORTA_PDR		(0x0008c00a)
#define	RX63N_PORTB_PDR		(0x0008c00b)
#define	RX63N_PORTC_PDR		(0x0008c00c)
#define	RX63N_PORTD_PDR		(0x0008c00d)
#define	RX63N_PORTE_PDR		(0x0008c00e)
#define	RX63N_PORTF_PDR		(0x0008c00f)
#define	RX63N_PORTG_PDR		(0x0008c010)
#define	RX63N_PORTJ_PDR		(0x0008c012)
#define	RX63N_PORT0_PODR	(0x0008c020)
#define	RX63N_PORT1_PODR	(0x0008c021)
#define	RX63N_PORT2_PODR	(0x0008c022)
#define	RX63N_PORT3_PODR	(0x0008c023)
#define	RX63N_PORT4_PODR	(0x0008c024)
#define	RX63N_PORT5_PODR	(0x0008c025)
#define	RX63N_PORT6_PODR	(0x0008c026)
#define	RX63N_PORT7_PODR	(0x0008c027)
#define	RX63N_PORT8_PODR	(0x0008c028)
#define	RX63N_PORT9_PODR	(0x0008c029)
#define	RX63N_PORTA_PODR	(0x0008c02a)
#define	RX63N_PORTB_PODR	(0x0008c02b)
#define	RX63N_PORTC_PODR	(0x0008c02c)
#define	RX63N_PORTD_PODR	(0x0008c02d)
#define	RX63N_PORTE_PODR	(0x0008c02e)
#define	RX63N_PORTF_PODR	(0x0008c02f)
#define	RX63N_PORTG_PODR	(0x0008c030)
#define	RX63N_PORTJ_PODR	(0x0008c032)
#define	RX63N_PORT0_PIDR	(0x0008c040)
#define	RX63N_PORT1_PIDR	(0x0008c041)
#define	RX63N_PORT2_PIDR	(0x0008c042)
#define	RX63N_PORT3_PIDR	(0x0008c043)
#define	RX63N_PORT4_PIDR	(0x0008c044)
#define	RX63N_PORT5_PIDR	(0x0008c045)
#define	RX63N_PORT6_PIDR	(0x0008c046)
#define	RX63N_PORT7_PIDR	(0x0008c047)
#define	RX63N_PORT8_PIDR	(0x0008c048)
#define	RX63N_PORT9_PIDR	(0x0008c049)
#define	RX63N_PORTA_PIDR	(0x0008c04a)
#define	RX63N_PORTB_PIDR	(0x0008c04b)
#define	RX63N_PORTC_PIDR	(0x0008c04c)
#define	RX63N_PORTD_PIDR	(0x0008c04d)
#define	RX63N_PORTE_PIDR	(0x0008c04e)
#define	RX63N_PORTF_PIDR	(0x0008c04f)
#define	RX63N_PORTG_PIDR	(0x0008c050)
#define	RX63N_PORTJ_PIDR	(0x0008c052)
#define	RX63N_PORT0_PMR		(0x0008c060)
#define	RX63N_PORT1_PMR		(0x0008c061)
#define	RX63N_PORT2_PMR		(0x0008c062)
#define	RX63N_PORT3_PMR		(0x0008c063)
#define	RX63N_PORT4_PMR		(0x0008c064)
#define	RX63N_PORT5_PMR		(0x0008c065)
#define	RX63N_PORT6_PMR		(0x0008c066)
#define	RX63N_PORT7_PMR		(0x0008c067)
#define	RX63N_PORT8_PMR		(0x0008c068)
#define	RX63N_PORT9_PMR		(0x0008c069)
#define	RX63N_PORTA_PMR		(0x0008c06a)
#define	RX63N_PORTB_PMR		(0x0008c06b)
#define	RX63N_PORTC_PMR		(0x0008c06c)
#define	RX63N_PORTD_PMR		(0x0008c06d)
#define	RX63N_PORTE_PMR		(0x0008c06e)
#define	RX63N_PORTF_PMR		(0x0008c06f)
#define	RX63N_PORTG_PMR		(0x0008c070)
#define	RX63N_PORTJ_PMR		(0x0008c072)


/*
 * ޥե󥯥ԥ󥳥ȥ(MPC)
 */
#define	RX63N_PWPR		(0x0008c11f)
#define	RX63N_P00PFS		(0x0008c140)
#define	RX63N_P01PFS		(0x0008c141)
#define	RX63N_P02PFS		(0x0008c142)
#define	RX63N_P03PFS		(0x0008c143)
#define	RX63N_P05PFS		(0x0008c145)
#define	RX63N_P07PFS		(0x0008c147)
#define	RX63N_P10PFS		(0x0008c148)
#define	RX63N_P11PFS		(0x0008c149)
#define	RX63N_P12PFS		(0x0008c14a)
#define	RX63N_P13PFS		(0x0008c14b)
#define	RX63N_P14PFS		(0x0008c14c)
#define	RX63N_P15PFS		(0x0008c14d)
#define	RX63N_P16PFS		(0x0008c14e)
#define	RX63N_P17PFS		(0x0008c14f)
#define	RX63N_P20PFS		(0x0008c150)
#define	RX63N_P21PFS		(0x0008c151)
#define	RX63N_P22PFS		(0x0008c152)
#define	RX63N_P23PFS		(0x0008c153)
#define	RX63N_P24PFS		(0x0008c154)
#define	RX63N_P25PFS		(0x0008c155)
#define	RX63N_P26PFS		(0x0008c156)
#define	RX63N_P27PFS		(0x0008c157)
#define	RX63N_P30PFS		(0x0008c158)
#define	RX63N_P31PFS		(0x0008c159)
#define	RX63N_P32PFS		(0x0008c15a)
#define	RX63N_P33PFS		(0x0008c15b)
#define	RX63N_P34PFS		(0x0008c15c)
#define	RX63N_P40PFS		(0x0008c160)
#define	RX63N_P41PFS		(0x0008c161)
#define	RX63N_P42PFS		(0x0008c162)
#define	RX63N_P43PFS		(0x0008c163)
#define	RX63N_P44PFS		(0x0008c164)
#define	RX63N_P45PFS		(0x0008c165)
#define	RX63N_P46PFS		(0x0008c166)
#define	RX63N_P47PFS		(0x0008c167)
#define	RX63N_P50PFS		(0x0008c168)
#define	RX63N_P51PFS		(0x0008c169)
#define	RX63N_P52PFS		(0x0008c16a)
#define	RX63N_P54PFS		(0x0008c16c)
#define	RX63N_P55PFS		(0x0008c16d)
#define	RX63N_P56PFS		(0x0008c16e)
#define	RX63N_P57PFS		(0x0008c16f)
#define	RX63N_P60PFS		(0x0008c170)
#define	RX63N_P61PFS		(0x0008c171)
#define	RX63N_P66PFS		(0x0008c176)
#define	RX63N_P67PFS		(0x0008c177)
#define	RX63N_P70PFS		(0x0008c178)
#define	RX63N_P71PFS		(0x0008c179)
#define	RX63N_P72PFS		(0x0008c17a)
#define	RX63N_P73PFS		(0x0008c17b)
#define	RX63N_P74PFS		(0x0008c17c)
#define	RX63N_P75PFS		(0x0008c17d)
#define	RX63N_P76PFS		(0x0008c17e)
#define	RX63N_P77PFS		(0x0008c17f)
#define	RX63N_P80PFS		(0x0008c180)
#define	RX63N_P81PFS		(0x0008c181)
#define	RX63N_P82PFS		(0x0008c182)
#define	RX63N_P83PFS		(0x0008c183)
#define	RX63N_P86PFS		(0x0008c186)
#define	RX63N_P87PFS		(0x0008c187)
#define	RX63N_P90PFS		(0x0008c188)
#define	RX63N_P91PFS		(0x0008c189)
#define	RX63N_P92PFS		(0x0008c18a)
#define	RX63N_P93PFS		(0x0008c18b)
#define	RX63N_PA0PFS		(0x0008c190)
#define	RX63N_PA1PFS		(0x0008c191)
#define	RX63N_PA2PFS		(0x0008c192)
#define	RX63N_PA3PFS		(0x0008c193)
#define	RX63N_PA4PFS		(0x0008c194)
#define	RX63N_PA5PFS		(0x0008c195)
#define	RX63N_PA6PFS		(0x0008c196)
#define	RX63N_PA7PFS		(0x0008c197)
#define	RX63N_PB0PFS		(0x0008c198)
#define	RX63N_PB1PFS		(0x0008c199)
#define	RX63N_PB2PFS		(0x0008c19a)
#define	RX63N_PB3PFS		(0x0008c19b)
#define	RX63N_PB4PFS		(0x0008c19c)
#define	RX63N_PB5PFS		(0x0008c19d)
#define	RX63N_PB6PFS		(0x0008c19e)
#define	RX63N_PB7PFS		(0x0008c19f)
#define	RX63N_PC0PFS		(0x0008c1a0)
#define	RX63N_PC1PFS		(0x0008c1a1)
#define	RX63N_PC2PFS		(0x0008c1a2)
#define	RX63N_PC3PFS		(0x0008c1a3)
#define	RX63N_PC4PFS		(0x0008c1a4)
#define	RX63N_PC5PFS		(0x0008c1a5)
#define	RX63N_PC6PFS		(0x0008c1a6)
#define	RX63N_PC7PFS		(0x0008c1a7)
#define	RX63N_PD0PFS		(0x0008c1a8)
#define	RX63N_PD1PFS		(0x0008c1a9)
#define	RX63N_PD2PFS		(0x0008c1aa)
#define	RX63N_PD3PFS		(0x0008c1ab)
#define	RX63N_PD4PFS		(0x0008c1ac)
#define	RX63N_PD5PFS		(0x0008c1ad)
#define	RX63N_PD6PFS		(0x0008c1ae)
#define	RX63N_PD7PFS		(0x0008c1af)
#define	RX63N_PE0PFS		(0x0008c1b0)
#define	RX63N_PE1PFS		(0x0008c1b1)
#define	RX63N_PE2PFS		(0x0008c1b2)
#define	RX63N_PE3PFS		(0x0008c1b3)
#define	RX63N_PE4PFS		(0x0008c1b4)
#define	RX63N_PE5PFS		(0x0008c1b5)
#define	RX63N_PE6PFS		(0x0008c1b6)
#define	RX63N_PE7PFS		(0x0008c1b7)
#define	RX63N_PF0PFS		(0x0008c1b8)
#define	RX63N_PF1PFS		(0x0008c1b9)
#define	RX63N_PF2PFS		(0x0008c1ba)
#define	RX63N_PF5PFS		(0x0008c1bd)
#define	RX63N_PJ3PFS		(0x0008c1d3)

/*
 * ڥޥå(CMT)
 */
#define	RX63N_CMSTR0		(0x00088000)
#define	RX63N_CMT0_CMCR		(0x00088002)
#define	RX63N_CMT0_CMCNT	(0x00088004)
#define	RX63N_CMT0_CMCOR	(0x00088006)
#define	RX63N_CMT1_CMCR		(0x00088008)
#define	RX63N_CMT1_CMCNT	(0x0008800a)
#define	RX63N_CMT1_CMCOR	(0x0008800c)
#define	RX63N_CMSTR1		(0x00088010)
#define	RX63N_CMT2_CMCR		(0x00088012)
#define	RX63N_CMT2_CMCNT	(0x00088014)
#define	RX63N_CMT2_CMCOR	(0x00088016)
#define	RX63N_CMT3_CMCR		(0x00088018)
#define	RX63N_CMT3_CMCNT	(0x0008801a)
#define	RX63N_CMT3_CMCOR	(0x0008801c)

/*
 * ꥢ륳ߥ˥󥤥󥿥ե(SCIcSCId)
 */
#define	RX63N_SCI0_SMR		(0x0008a000)
#define	RX63N_SCI0_BRR		(0x0008a001)
#define	RX63N_SCI0_SCR		(0x0008a002)
#define	RX63N_SCI0_TDR		(0x0008a003)
#define	RX63N_SCI0_SSR		(0x0008a004)
#define	RX63N_SCI0_RDR		(0x0008a005)
#define	RX63N_SCI0_SCMR		(0x0008a006)
#define	RX63N_SCI0_SEMR		(0x0008a007)
#define	RX63N_SCI0_SIMR1	(0x0008a009)
#define	RX63N_SCI0_SIMR2	(0x0008a00a)
#define	RX63N_SCI0_SIMR3	(0x0008a00b)
#define	RX63N_SCI0_SISR		(0x0008a00c)
#define	RX63N_SCI0_SPMR		(0x0008a00d)
#define	RX63N_SCI1_SMR		(0x0008a020)
#define	RX63N_SCI1_BRR		(0x0008a021)
#define	RX63N_SCI1_SCR		(0x0008a022)
#define	RX63N_SCI1_TDR		(0x0008a023)
#define	RX63N_SCI1_SSR		(0x0008a024)
#define	RX63N_SCI1_RDR		(0x0008a025)
#define	RX63N_SCI1_SCMR		(0x0008a026)
#define	RX63N_SCI1_SEMR		(0x0008a027)
#define	RX63N_SCI1_SIMR1	(0x0008a029)
#define	RX63N_SCI1_SIMR2	(0x0008a02a)
#define	RX63N_SCI1_SIMR3	(0x0008a02b)
#define	RX63N_SCI1_SISR		(0x0008a02c)
#define	RX63N_SCI1_SPMR		(0x0008a02d)
#define	RX63N_SCI2_SMR		(0x0008a040)
#define	RX63N_SCI2_BRR		(0x0008a041)
#define	RX63N_SCI2_SCR		(0x0008a042)
#define	RX63N_SCI2_TDR		(0x0008a043)
#define	RX63N_SCI2_SSR		(0x0008a044)
#define	RX63N_SCI2_RDR		(0x0008a045)
#define	RX63N_SCI2_SCMR		(0x0008a046)
#define	RX63N_SCI2_SEMR		(0x0008a047)
#define	RX63N_SCI2_SIMR1	(0x0008a049)
#define	RX63N_SCI2_SPMR		(0x0008a04d)
#define	RX63N_SCI3_SMR		(0x0008a060)
#define	RX63N_SCI3_BRR		(0x0008a061)
#define	RX63N_SCI3_SCR		(0x0008a062)
#define	RX63N_SCI3_TDR		(0x0008a063)
#define	RX63N_SCI3_SSR		(0x0008a064)
#define	RX63N_SCI3_RDR		(0x0008a065)
#define	RX63N_SCI3_SCMR		(0x0008a066)
#define	RX63N_SCI3_SEMR		(0x0008a067)
#define	RX63N_SCI3_SIMR1	(0x0008a069)
#define	RX63N_SCI3_SPMR		(0x0008a06d)
#define	RX63N_SCI4_SMR		(0x0008a080)
#define	RX63N_SCI4_BRR		(0x0008a081)
#define	RX63N_SCI4_SCR		(0x0008a082)
#define	RX63N_SCI4_TDR		(0x0008a083)
#define	RX63N_SCI4_SSR		(0x0008a084)
#define	RX63N_SCI4_RDR		(0x0008a085)
#define	RX63N_SCI4_SCMR		(0x0008a086)
#define	RX63N_SCI4_SEMR		(0x0008a087)
#define	RX63N_SCI4_SIMR1	(0x0008a089)
#define	RX63N_SCI4_SPMR		(0x0008a08d)
#define	RX63N_SCI5_SMR		(0x0008a0a0)
#define	RX63N_SCI5_BRR		(0x0008a0a1)
#define	RX63N_SCI5_SCR		(0x0008a0a2)
#define	RX63N_SCI5_TDR		(0x0008a0a3)
#define	RX63N_SCI5_SSR		(0x0008a0a4)
#define	RX63N_SCI5_RDR		(0x0008a0a5)
#define	RX63N_SCI5_SCMR		(0x0008a0a6)
#define	RX63N_SCI5_SEMR		(0x0008a0a7)
#define	RX63N_SCI5_SIMR1	(0x0008a0a9)
#define	RX63N_SCI5_SPMR		(0x0008a0ad)
#define	RX63N_SCI6_SMR		(0x0008a0c0)
#define	RX63N_SCI6_BRR		(0x0008a0c1)
#define	RX63N_SCI6_SCR		(0x0008a0c2)
#define	RX63N_SCI6_TDR		(0x0008a0c3)
#define	RX63N_SCI6_SSR		(0x0008a0c4)
#define	RX63N_SCI6_RDR		(0x0008a0c5)
#define	RX63N_SCI6_SCMR		(0x0008a0c6)
#define	RX63N_SCI6_SEMR		(0x0008a0c7)
#define	RX63N_SCI6_SIMR1	(0x0008a0c9)
#define	RX63N_SCI6_SPMR		(0x0008a0cd)
#define	RX63N_SCI7_SMR		(0x0008a0e0)
#define	RX63N_SCI7_BRR		(0x0008a0e1)
#define	RX63N_SCI7_SCR		(0x0008a0e2)
#define	RX63N_SCI7_TDR		(0x0008a0e3)
#define	RX63N_SCI7_SSR		(0x0008a0e4)
#define	RX63N_SCI7_RDR		(0x0008a0e5)
#define	RX63N_SCI7_SCMR		(0x0008a0e6)
#define	RX63N_SCI7_SEMR		(0x0008a0e7)
#define	RX63N_SCI7_SIMR1	(0x0008a0e9)
#define	RX63N_SCI7_SPMR		(0x0008a0ed)
#define	RX63N_SCI8_SMR		(0x0008a100)
#define	RX63N_SCI8_BRR		(0x0008a101)
#define	RX63N_SCI8_SCR		(0x0008a102)
#define	RX63N_SCI8_TDR		(0x0008a103)
#define	RX63N_SCI8_SSR		(0x0008a104)
#define	RX63N_SCI8_RDR		(0x0008a105)
#define	RX63N_SCI8_SCMR		(0x0008a106)
#define	RX63N_SCI8_SEMR		(0x0008a107)
#define	RX63N_SCI8_SIMR1	(0x0008a109)
#define	RX63N_SCI8_SPMR		(0x0008a10d)
#define	RX63N_SCI9_SMR		(0x0008a120)
#define	RX63N_SCI9_BRR		(0x0008a121)
#define	RX63N_SCI9_SCR		(0x0008a122)
#define	RX63N_SCI9_TDR		(0x0008a123)
#define	RX63N_SCI9_SSR		(0x0008a124)
#define	RX63N_SCI9_RDR		(0x0008a125)
#define	RX63N_SCI9_SCMR		(0x0008a126)
#define	RX63N_SCI9_SEMR		(0x0008a127)
#define	RX63N_SCI9_SIMR1	(0x0008a129)
#define	RX63N_SCI9_SPMR		(0x0008a12d)
#define	RX63N_SCI10_SMR		(0x0008a140)
#define	RX63N_SCI10_BRR		(0x0008a141)
#define	RX63N_SCI10_SCR		(0x0008a142)
#define	RX63N_SCI10_TDR		(0x0008a143)
#define	RX63N_SCI10_SSR		(0x0008a144)
#define	RX63N_SCI10_RDR		(0x0008a145)
#define	RX63N_SCI10_SCMR	(0x0008a146)
#define	RX63N_SCI10_SEMR	(0x0008a147)
#define	RX63N_SCI10_SIMR1	(0x0008a149)
#define	RX63N_SCI10_SPMR	(0x0008a14d)
#define	RX63N_SCI11_SMR		(0x0008a160)
#define	RX63N_SCI11_BRR		(0x0008a161)
#define	RX63N_SCI11_SCR		(0x0008a162)
#define	RX63N_SCI11_TDR		(0x0008a163)
#define	RX63N_SCI11_SSR		(0x0008a164)
#define	RX63N_SCI11_RDR		(0x0008a165)
#define	RX63N_SCI11_SCMR	(0x0008a166)
#define	RX63N_SCI11_SEMR	(0x0008a167)
#define	RX63N_SCI11_SIMR1	(0x0008a169)
#define	RX63N_SCI11_SPMR	(0x0008a16d)
#define	RX63N_SCI12_SMR		(0x0008a180)
#define	RX63N_SCI12_BRR		(0x0008a181)
#define	RX63N_SCI12_SCR		(0x0008a182)
#define	RX63N_SCI12_TDR		(0x0008a183)
#define	RX63N_SCI12_SSR		(0x0008a184)
#define	RX63N_SCI12_RDR		(0x0008a185)
#define	RX63N_SCI12_SCMR	(0x0008a186)
#define	RX63N_SCI12_SEMR	(0x0008a187)
#define	RX63N_SCI12_SIMR1	(0x0008a189)
#define	RX63N_SCI12_SPMR	(0x0008a18d)

#endif	/* _RX63N_H_ */
